#
# spec file for package gegl
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define debug_package_requires libgegl-0_2-0 = %{version}-%{release}
Name:           gegl
Version:        0.2.0
Release:        16.23
Summary:        Generic Graphics Library
License:        GPL-3.0+ and LGPL-3.0+
Group:          System/Libraries
Url:            http://gegl.org/
Source:         http://ftp.gtk.org/pub/gegl/0.2/%{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM gegl-lua52.patch bgo#667675 vuntz@opensuse.org -- Fix build with lua 5.2
Patch0:         gegl-lua52.patch
# PATCH-FIX-UPSTREAM gegl-ruby19.patch dimstar@opensuse.org -- Fix build with ruby 1.9
Patch1:         gegl-ruby19.patch
# Patched code is built by default.
# Use rpmbuild -D 'BUILD_ORIG 1' to build original code.
# Use rpmbuild -D 'BUILD_ORIG 1' -D 'BUILD_ORIG_ADDON 1' to build patched build plus original as addon.
# PATCH-FIX-UPSTREAM sutesparse changed UF_long for SuiteSparse_long
Patch2:         gegl-UF_long.patch
# PATCH-FIX-UPSTREAM gegl-0.2.0-linker-flags.patch idoenmez@suse.de -- Add -lm to linker flags
Patch3:         gegl-0.2.0-linker-flags.patch
# PATCH-FIX-SECURITY gegl-0.2.0-CVE-2012-4433.patch bsc789835 CVE-2012-4433 zaitor@opensuse.org -- Fix buffer overflow in and add plausibility checks to ppm-load op
Patch4:         gegl-0.2.0-CVE-2012-4433.patch
BuildRequires:  ImageMagick
BuildRequires:  OpenEXR-devel
BuildRequires:  SDL-devel
BuildRequires:  asciidoc
BuildRequires:  babl-devel >= 0.1.10
BuildRequires:  enscript
BuildRequires:  gcc-c++
# multiple provides by gd and gd-tools
BuildRequires:  gd
BuildRequires:  glib2-devel >= 2.16.1
BuildRequires:  graphviz-gd
# Only for directory ownership:
BuildRequires:  gtk-doc
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  lensfun-devel
# Needed to build the doc, as Bitstream Vera Sans is the referenced font.
BuildRequires:  liberation-fonts
BuildRequires:  libexiv2-devel
BuildRequires:  libjasper-devel >= 1.900.1
BuildRequires:  libjpeg-devel
BuildRequires:  libopenraw-devel >= 0.0.5
BuildRequires:  libpng-devel
BuildRequires:  librsvg-devel
BuildRequires:  libspiro-devel
BuildRequires:  libstdc++-devel
BuildRequires:  lua-devel
BuildRequires:  ruby
# For umfpack
BuildRequires:  suitesparse-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?BUILD_ORIG}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libswscale)
%if 0%{?BUILD_ORIG_ADDON}
Provides:       patched_subset
%else
Provides:       %{name}-orig-addon = %{version}
Obsoletes:      %{name}-orig-addon
%endif
%else
Provides:       patched_subset
%endif

%description
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%package 0_2
Summary:        Generic Graphics Library
Group:          System/Libraries
Recommends:     %{name}-0_2-lang

%description 0_2
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%if 0%{?BUILD_ORIG}
%if 0%{?BUILD_ORIG_ADDON}
%package 0_2-orig-addon
Summary:        Generic Graphics Library
Group:          System/Libraries
Supplements:    packageand(%{name}-0_2:%(cd %{_libdir} ; rpm -qf --queryformat=%%{NAME} `readlink %{_libdir}/libavcodec.so` ))

%description 0_2-orig-addon
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%endif
%endif

%package -n libgegl-0_2-0
Summary:        Generic Graphics Library
Group:          System/Libraries
Recommends:     %{name}-0_2 >= %{version}

%description -n libgegl-0_2-0
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%package devel
Summary:        Generic Graphics Library
Group:          System/Libraries
Requires:       babl-devel
Requires:       glib2-devel
Requires:       glibc-devel
Requires:       libgegl-0_2-0 = %{version}
Requires:       pcre-devel

%description devel
GEGL provides infratructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%package doc
Summary:        Generic Graphics Library
Group:          System/Libraries
Requires:       libgegl-0_2-0 = %{version}

%description doc
GEGL provides infrastructure to do demand based cached non destructive
image editing on larger than RAM buffers. Through babl it provides
support for a wide range of color models and pixel storage formats for
input and output.

%lang_package -n %{name}-0_2

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%if 0%{?suse_version} > 1310
%patch2 -p1
%endif
%patch3 -p1
# docs-build-fix.diff
%patch4 -p1

%build
export RPM_OPT_FLAGS="%{optflags} -fno-strict-aliasing"
## do not use autogen.sh, it intentionally fails, if there is no ruby.
## so why use autogen, when you do not want portability?
# ./autogen.sh
%configure\
	--enable-workshop=yes\
	--disable-static --disable-silent-rules
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%if ! 0%{?BUILD_ORIG}
for MODULE in \
%{_libdir}/gegl-0.2/ff-load.so \
; do
    rm -f %{buildroot}$MODULE
done
%endif
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}-0.2 %{?no_lang_C}

%post -n libgegl-0_2-0 -p /sbin/ldconfig

%postun -n libgegl-0_2-0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/gegl

%files 0_2
%defattr(-,root,root)
%dir %{_libdir}/gegl-0.2/
%{_libdir}/gegl-0.2/*.so
%if 0%{?BUILD_ORIG}
%if 0%{?BUILD_ORIG_ADDON}
%exclude %{_libdir}/gegl-0.2/ff-load.so

%files 0_2-orig-addon
%defattr(-,root,root)
%{_libdir}/gegl-0.2/ff-load.so
%endif
%endif

%files -n libgegl-0_2-0
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING.LESSER ChangeLog NEWS README
%{_libdir}/libgegl-0.2.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/gegl-0.2/
%{_libdir}/libgegl-0.2.so
%{_libdir}/pkgconfig/gegl-0.2.pc

%files doc
%defattr(-,root,root)
%doc %{_datadir}/gtk-doc/html/gegl/

%files -n %{name}-0_2-lang -f %{name}-0.2.lang
%defattr(-,root,root)

%changelog
* Sun Feb  5 2017 zaitor@opensuse.org
- Fix CVE-2012-4433 (bsc#789835):
  + Add gegl-0.2.0-CVE-2012-4433.patch: Fix buffer overflow in and
    add plausibility checks to ppm-load op.
* Sat Apr 16 2016 olaf@aepfle.de
- Use pkgconfig instead of libffmpeg-devel
* Tue Jan 26 2016 idonmez@suse.com
- Add gegl-0.2.0-linker-flags.patch to add -lm to linker flags
* Sat Oct 25 2014 i@marguerite.su
- fix build for factory
  * add patch: gegl-UF_long.patch
  * newer suitesparse abandoned UF_long in favor for SuiteSparse_long
- fix build for graphics repo
  * ugly fix, multiple provides of gd by gd and gd-tools from libgd2
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Fri May 18 2012 dimstar@opensuse.org
- Add gegl-ruby19.patch: Fix build with ruby 1.9.
- Add liberation-fonts: the documentation references bitstream
  vera sans font, so we need to provide it for the build.
* Tue Apr  3 2012 vuntz@opensuse.org
- Update to version 0.2.0:
  + OpenCL support
  + Build improvements.
  + High level API to apply ops directly to buffers with arguments.
  + Final bits of translation infrastructure.
  + Invalidate regions when disconnecting input pads.
  + Operations:
  - New operation: global-matting
  - Allow transform core to do perspective transforms.
  - Added string based key/value pairs to operations.
  - Added arguments for dealing with scaled down preview
    rendering.
  + Added human interaction ranges and non-linear mapping to
    properties.
  + Buffer:
  - Removed broken lanczos sampler.
  - Add gegl_buffer_set_color and gegl_buffer_set_pattern
  - Added ability to drop cached tiles.
  - Added API for handling abyss policy (not implemented yet)
  - Avoid iterating global tile cache when flushing/destroying
    buffers that have no tiles in the cache.
- Add intltool BuildRequires: new dependency upstream, for
  translations.
- Add lensfun-devel BuildRequires to build with lensfun support.
- Add libexiv2-devel BuildRequires to build with libexiv2 support.
- Add libjasper-devel BuildRequires to build with Jasper support.
- Add libspiro-devel BuildRequires to build with SPIRO support.
- Add suitesparse-devel BuildRequires to build with UMFPACK
  support.
- Uncomment ruby BuildRequires: it was commented out because a file
  was missing in a earlier tarball.
- Rename subpackages from gegl-0_1/libgegl-0_1-0 to
  gegl-0_2/libgegl-0_2-0 following the upstream soname change.
- Create a gegl-0_2-lang subpackage for new translations.
* Wed Jan 11 2012 vuntz@opensuse.org
- Add gegl-lua52.patch: fix build with lua 5.2, while still being
  compatible with lua 5.1.
* Sun Nov 27 2011 dimstar@opensuse.org
- Update to version 0.1.8:
  + New operations: spread, vignette, map-relative,
    noise-reduction, plasma, fractal-trace, exr-save, lens-correct,
    emboss, cubism, ripple, color-to-alpha, color-rotate,
    red-eye-removal, convolution-matrix, deinterlace,
    polar-coordinates, lens-distortion, pixelise.
  + Split GeglView GTK Widget into separate utility library
  + build/test improvements.
  + Buffer:
  - Added lohalo resampler, API and infrastructure for doing non
    affine resamplings.
- Clean spec-file using spec-cleaner.
- Drop docs-build-fix.diff: fixed upstream.
* Mon Jun 20 2011 jw@novell.com
- update to 0.1.6 (see NEWS)
  • New operations: max-rgb, pixelise, motion blur.
  • Fixed a bugs in matting-levin that made GEGL halt due to errors
  detected by babl sanity code, this made 0.1.4 be unusable if you had
  all dependendency when building.
  • build/test improvements.
  • Buffer:
    Added API to use external tile backends, allowing to plug-in alien
    tilebackends, for GIMP/Krita/OSM or similar.
- remove upstreamed patches bgo609706 bgo610680 (thanks, Vincent)
* Thu May  5 2011 dimstar@opensuse.org
- BuildRequire graphviz-gd instead of graphviz: we do require png
  capabilities, which are split out of the main package.
  Theoretically, we should require graphviz-devel, but this package
  also does not drag in -gd.
* Mon Feb 22 2010 vuntz@opensuse.org
- Add gegl-fix-overflow.patch to fix overflow found by gcc 4.5.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 0.1.2:
  + GeglLookup, configurable floating point lookup tables for lazy
    computation.
  + Use GFileIOStream in GeglTileBackendFile.
  + Optimizations: in-place processing for point filters/composers,
    SIMD version of gegl:opacity, avoid making unneccesary
    sub-buffers, removed some  manual instrumentation from critical
    paths, improved speed of samplers.
  + Added xml composition/reference image based regression tests.
  + Added performance tracking framework.
  + Syntactic sugar using varargs for constructing gegl graphs from
    C.
  + Build fixes on cygwin.
  + Gegl# fixes.
  + Initial, but unstable code towards multithreading.
  + Improvements to lua op in workshop.
  + Added new resamplers upsize, upsharp, upsmooth, downsize,
    downsharp and downsmooth.
  + Removed gegl:tonemap and gegl:normal ops.
- Drop gegl-new-babl.patch: fixed upstream.
- Add gegl-fix-build.patch: remove printf that breaks build because
  of missing include.
- Rename package from gegl-0_0 and libgegl-0_0-0 to gegl-0_1 and
  libgegl-0_1-0 following soname bump.
* Thu Jan 28 2010 vuntz@opensuse.org
- Add gegl-new-babl.patch to fix build with babl 0.1.2.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 0.1.0:
  + Renamed gegl:load-buffer to gegl:buffer-source and
    gegl:save-buffer to gegl:buffer-sink (but the old names still
    work)
  + Represent colors using doubles instead of floats (this change
    is independent from internal processing)
  + Removed the GTK+ UI parts of the gegl binary and turned gegl
    into a pure command line tool (which can still visualize stuff
    with help help the SDL based display operation)
  + Consider {x=G_MININT/2, y=G_MININT/2, width=G_MAXINT,
    height=G_MAXINT} as the only valid region wichin processing
    may occur. Processing outside of this region is undefined
    behaviour.
  + Added support for storing allocation stack traces for
    GeglBuffers so that debuging buffer leaks becomes much easier
  + Made small changes and cleanups of the public API, e.g.
  - Removed gegl_node_adapt_child()
  - Made GeglConfig an explicit object
  - Removed most of the ifdeffed stuff to mask away internal
    structures
  - Added gegl_rectangle_infinite_plane() and
    gegl_rectangle_is_infinite_plane()
  + Added new sampler GeglSamplerSharp
  + Added format property go gegl:buffer-sink
  + Cleaned up and made gegl:introspect work again
  + Add a bunch of test cases using the automake test sytem (make
    check) and also port buffer tests to automake
  + General cleanups, bug fixes, increased robustness and improved
    documentation
- Drop gegl-babl_api_change.patch: fixed upstream.
- Temporarly remove ruby BuildRequires as the build is broken when
  it's there right now.
* Thu Jun 11 2009 vuntz@novell.com
- Add gegl-babl_api_change.patch to make gegl build with babl
  0.1.0. Patch taken from Fedora.
- Remove autoreconf call.
- Do not make gegl0_0 explicitly Requires libbabl-0_0-0.
* Wed Dec 31 2008 hfiguiere@suse.de
- Update to 0.0.22
  * GeglOperation
  - operation names are now prefixed, the ops in GEGL use 'gegl:' as prefix.
  - gegl:opacity - combine value and aux mask input when both are available.
  - gegl:src-in - deal correctly with extens.
  - gegl:path - new op covering the stroke/fill needs of SVG.
  - deprecated gegl:shift, the affine familiy of operations now
    uses the same fast code paths for integer translations.
  * GeglBuffer
  - Profiling motivated speed ups in data reading/writing.
  - Remove left-over swapfiles from dead processes at startup.
  * GeglNode
  - made gegl_node_add_child and gegl_node_remove_child public API. (bgo#507298)
  * GeglPath: Vector path representation infrastructure,
- Remove gegl-64bit-warning.diff
* Mon Oct  6 2008 hfiguiere@suse.de
- Update to 0.0.20
  * libopenraw support
  * Linear buffer support, amongst other things enabling GeglBuffer API access
    to external linear buffers in memory.
  * Reworked samplers using a shared caching neighbourhood infrastructure.
  * YAFR - a new resampler contributed by Nicolas Robidoux.
  * Marked user visible strings for translation.
  * Added a fill operation (might be a bit fragile) that allows rendering
    SVG like paths backed by a GeglVector.
- Remove gegl-strict-compile-fix.diff
- Added gegl-64bit-warning.diff
  * Address a fatal warning on 64bits
* Wed Oct  1 2008 hfiguiere@suse.de
- Add patch gegl-strict-compile-fix.diff:
  * Fix header for stricter compilation
- enable workshop at compile time
* Mon Sep 29 2008 sbrabec@suse.cz
- Fixed dependencies.
- Fixed permissions of documentation.
* Mon Jul 21 2008 sbrabec@suse.cz
- New SuSE package.
